@@ -28,6 +28,9 @@ std::shared_ptr<arrow::csv::ReadOptions> csv___ReadOptions__initialize(List_ opt
       std::make_shared<arrow::csv::ReadOptions>(arrow::csv::ReadOptions::Defaults());
   res->use_threads = options["use_threads"];
   res->block_size = options["block_size"];
+  res->skip_rows = options["skip_rows"];
+  res->column_names = Rcpp::as<std::vector<std::string>>(options["column_names"]);
+  res->autogenerate_column_names = options["autogenerate_column_names"];
   return res;
 }
 
@@ -43,7 +46,6 @@ std::shared_ptr<arrow::csv::ParseOptions> csv___ParseOptions__initialize(List_ o
   res->double_quote = options["double_quote"];
   res->escape_char = get_char(options["escape_char"]);
   res->newlines_in_values = options["newlines_in_values"];
-  res->header_rows = options["header_rows"];
   res->ignore_empty_lines = options["ignore_empty_lines"];
   return res;
 }
@@ -54,6 +56,19 @@ std::shared_ptr<arrow::csv::ConvertOptions> csv___ConvertOptions__initialize(
   auto res = std::make_shared<arrow::csv::ConvertOptions>(
       arrow::csv::ConvertOptions::Defaults());
   res->check_utf8 = options["check_utf8"];
+  // Recognized spellings for null values
+  res->null_values = Rcpp::as<std::vector<std::string>>(options["null_values"]);
+  // Whether string / binary columns can have null values.
+  // If true, then strings in "null_values" are considered null for string columns.
+  // If false, then all strings are valid string values.
+  res->strings_can_be_null = options["strings_can_be_null"];
+  // TODO: there are more conversion options available:
+  // // Optional per-column types (disabling type inference on those columns)
+  // std::unordered_map<std::string, std::shared_ptr<DataType>> column_types;
+  // // Recognized spellings for boolean values
+  // std::vector<std::string> true_values;
+  // std::vector<std::string> false_values;
+
   return res;
 }
 
