@@ -17,24 +17,26 @@
 
 context("Feather")
 
+feather_file <- tempfile()
+tib <- tibble::tibble(x = 1:10, y = rnorm(10), z = letters[1:10])
+
+test_that("Write a feather file", {
+  write_feather(tib, feather_file)
+  expect_true(fs::file_exists(feather_file))
+})
+
 test_that("feather read/write round trip", {
-  tib <- tibble::tibble(x = 1:10, y = rnorm(10), z = letters[1:10])
-
-  tf1 <- tempfile()
-  write_feather(tib, tf1)
-  expect_true(fs::file_exists(tf1))
-
   tf2 <- fs::path_abs(tempfile())
   write_feather(tib, tf2)
   expect_true(fs::file_exists(tf2))
 
   tf3 <- tempfile()
-  stream <- FileOutputStream(tf3)
+  stream <- FileOutputStream$create(tf3)
   write_feather(tib, stream)
   stream$close()
   expect_true(fs::file_exists(tf3))
 
-  tab1 <- read_feather(tf1)
+  tab1 <- read_feather(feather_file)
   expect_is(tab1, "data.frame")
 
   tab2 <- read_feather(tf2)
@@ -48,7 +50,7 @@ test_that("feather read/write round trip", {
   expect_is(tab4, "data.frame")
 
   # reading directly from arrow::io::ReadableFile
-  tab5 <- read_feather(ReadableFile(tf3))
+  tab5 <- read_feather(ReadableFile$create(tf3))
   expect_is(tab5, "data.frame")
 
   expect_equal(tib, tab1)
@@ -57,76 +59,51 @@ test_that("feather read/write round trip", {
   expect_equal(tib, tab4)
   expect_equal(tib, tab5)
 
-  unlink(tf1)
   unlink(tf2)
   unlink(tf3)
 })
 
 test_that("feather handles col_select = <names>", {
-  tib <- tibble::tibble(x = 1:10, y = rnorm(10), z = letters[1:10])
-
-  tf1 <- tempfile()
-  write_feather(tib, tf1)
-  expect_true(fs::file_exists(tf1))
-
-  tab1 <- read_feather(tf1, col_select = c("x", "y"))
+  tab1 <- read_feather(feather_file, col_select = c("x", "y"))
   expect_is(tab1, "data.frame")
 
   expect_equal(tib$x, tab1$x)
   expect_equal(tib$y, tab1$y)
-
-  unlink(tf1)
 })
 
 test_that("feather handles col_select = <integer>", {
-  tib <- tibble::tibble(x = 1:10, y = rnorm(10), z = letters[1:10])
-
-  tf1 <- tempfile()
-  write_feather(tib, tf1)
-  expect_true(fs::file_exists(tf1))
-
-  tab1 <- read_feather(tf1, col_select = 1:2)
+  tab1 <- read_feather(feather_file, col_select = 1:2)
   expect_is(tab1, "data.frame")
 
   expect_equal(tib$x, tab1$x)
   expect_equal(tib$y, tab1$y)
-  unlink(tf1)
 })
 
 test_that("feather handles col_select = <tidyselect helper>", {
-  tib <- tibble::tibble(x = 1:10, y = rnorm(10), z = letters[1:10])
-
-  tf1 <- tempfile()
-  write_feather(tib, tf1)
-  expect_true(fs::file_exists(tf1))
-
-  tab1 <- read_feather(tf1, col_select = everything())
+  tab1 <- read_feather(feather_file, col_select = everything())
   expect_identical(tib, tab1)
 
-  tab2 <- read_feather(tf1, col_select = starts_with("x"))
+  tab2 <- read_feather(feather_file, col_select = starts_with("x"))
   expect_identical(tab2, tib[, "x", drop = FALSE])
 
-  tab3 <- read_feather(tf1, col_select = c(starts_with("x"), contains("y")))
+  tab3 <- read_feather(feather_file, col_select = c(starts_with("x"), contains("y")))
   expect_identical(tab3, tib[, c("x", "y"), drop = FALSE])
 
-  tab4 <- read_feather(tf1, col_select = -z)
+  tab4 <- read_feather(feather_file, col_select = -z)
   expect_identical(tab4, tib[, c("x", "y"), drop = FALSE])
-
-  unlink(tf1)
 })
 
 test_that("feather read/write round trip", {
-  tib <- tibble::tibble(x = 1:10, y = rnorm(10), z = letters[1:10])
-
-  tf1 <- tempfile()
-  write_feather(tib, tf1)
-  expect_true(fs::file_exists(tf1))
-
-  tab1 <- read_feather(tf1, as_tibble = FALSE)
-  expect_is(tab1, "arrow::Table")
+  tab1 <- read_feather(feather_file, as_data_frame = FALSE)
+  expect_is(tab1, "Table")
 
   expect_equal(tib, as.data.frame(tab1))
-  unlink(tf1)
 })
 
+test_that("Read feather from raw vector", {
+  test_raw <- readBin(feather_file, what = "raw", n = 5000)
+  df <- read_feather(test_raw)
+  expect_is(df, "data.frame")
+})
 
+unlink(feather_file)
